diff --git a/htdocs/core/modules/product_batch/mod_batch_advanced.php b/htdocs/core/modules/product_batch/mod_lot_advanced.php
similarity index 90%
rename from htdocs/core/modules/product_batch/mod_batch_advanced.php
rename to htdocs/core/modules/product_batch/mod_lot_advanced.php
index cdf0ce3a70b..67ce3dd3704 100644
--- a/htdocs/core/modules/product_batch/mod_batch_advanced.php
+++ b/htdocs/core/modules/product_batch/mod_lot_advanced.php
@@ -22,9 +22,9 @@
*/
/**
- * \file htdocs/core/modules/product_batch/mod_batch_advanced.php
+ * \file htdocs/core/modules/product_batch/mod_lot_advanced.php
* \ingroup productbatch
* \brief File containing class for numbering model of Batch advanced
*/
require_once DOL_DOCUMENT_ROOT.'/core/modules/product_batch/modules_product_batch.class.php';
@@ -33,7 +33,7 @@ require_once DOL_DOCUMENT_ROOT.'/core/modules/product_batch/modules_product_batc
/**
* Class to manage Batch numbering rules advanced
*/
-class mod_batch_advanced extends ModeleNumRefBatch
+class mod_lot_advanced extends ModeleNumRefBatch
{
/**
* Dolibarr version of the loaded document
@@ -49,7 +49,7 @@ class mod_batch_advanced extends ModeleNumRefBatch
/**
* @var string name
*/
- public $name = 'advanced';
+ public $name = 'lot_advanced';
/**
@@ -68,8 +68,8 @@ class mod_batch_advanced extends ModeleNumRefBatch
$texte = $langs->trans('GenericNumRefModelDesc')."
\n";
$texte .= '
@@ -22,9 +22,9 @@
* \ingroup productbatch
- * \brief File containing class for numbering model of Batch advanced
+ * \brief File containing class for numbering model of Lot advanced
*/
require_once DOL_DOCUMENT_ROOT.'/core/modules/product_batch/modules_product_batch.class.php';